import os
import codecs
import re
from setuptools import setup

here = os.path.abspath(os.path.dirname(__file__))


def read(*parts):
    # intentionally *not* adding an encoding option to open
    return codecs.open(os.path.join(here, *parts), 'r').read()


def find_version(*file_paths):
    version_file = read(*file_paths)
    version_match = re.search(r"^__version__ = ['\"]([^'\"]*)['\"]",
                              version_file, re.M)
    if version_match:
        return version_match.group(1)
    raise RuntimeError("Unable to find version string.")


long_description = read('README.md') + '\n' + read('Changes.md')


setup(
    name='colourettu',
    version=find_version('colourettu', '__init__.py'),
    url='http://github.com/minchinweb/colourettu',
    license='MIT License',
    author='William Minchin',
    install_requires=['',
                      ],
    author_email='w_minchin@hotmail.com',
    description='Colour related functions',
    long_description=long_description,
    packages=['colourettu'],
    package_data={'': ['README.md', 'Changes.md', 'LICENSE']},
    include_package_data=True,
    platforms='any',
    classifiers=[
        'Programming Language :: Python',
        'Development Status :: 2 - Pre-Alpha',
        'Natural Language :: English',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Multimedia :: Graphics',
        ],
)
